@@ -1,4 +1,5 @@
 library(statmod)
+options(warnPartialMatchArgs=TRUE,warnPartialMatchAttr=TRUE,warnPartialMatchDollar=TRUE)
 
 set.seed(0); u <- runif(100)
 
@@ -16,28 +17,30 @@ glmgam.fit(c(1,1),c(0,4))
 glmgam.fit(X=cbind(1,c(1,0.5,0.5,0,0)),y=rchisq(5,df=1))
 
 ### glmnb.fit
+
 y <- rnbinom(5,mu=10,size=10)
 glmnb.fit(X=cbind(1,c(1,0.5,0.5,0,0)),y=y,dispersion=0.1)
 glmnb.fit(X=cbind(1,c(1,0.5,0.5,0,0)),y=y,dispersion=runif(6))
 glmnb.fit(X=cbind(1,c(1,1,0,0,0)),y=c(0,0,6,2,9),dispersion=0.1)
+fit <- glmnb.fit(X=cbind(1,c(1,1,0,0,0)),y=c(0,0,0,0,0),dispersion=0.1)
+fit$coefficients <- zapsmall(fit$coefficients,digits=15)
+fit
+X <- matrix(rnorm(10),5,2)
+glmnb.fit(X,y=c(0,0,0,0,0),offset=rnorm(5),dispersion=0.05)
 
 ### mixedModel2
 
 y <- rnorm(6)
 x <- rnorm(6)
 z <- c(1,1,2,2,3,3)
-m <- mixedModel2(y~x,random=z)
-m$reml.residuals <- m$qr <- NULL
-m
+mixedModel2(y~x,random=z)
 
 ### mixedModel2Fit
 
 y <- c(-1,1,-2,2,0.5,1.7,-0.1)
 X <- matrix(1,7,1)
 Z <- model.matrix(~0+factor(c(1,1,2,2,3,3,4)))
-m <- mixedModel2Fit(y,X,Z)
-m$reml.residuals <- m$qr <- NULL
-m
+mixedModel2Fit(y,X,Z)
 
 ### qresiduals
 
@@ -90,7 +93,7 @@ qinvgauss(p,mean=1.3,dispersion=0.6,lower.tail=FALSE)
 qinvgauss(0.5,mean=c(1,2,NA))
 qinvgauss(log(p),mean=1.3,dispersion=0.6,log.p=TRUE)
 qinvgauss(log(p),mean=1.3,dispersion=0.6,lower.tail=FALSE,log.p=TRUE)
-
+rinvgauss(5,mean=c(1,NA,3,Inf,1e10),dispersion=c(2,3,NA,Inf,4))
 
 ### extra tests done only locally
 
